@@ -158,7 +158,7 @@ class TestScrapersRegionalToplevel:
             outputs,
             regional_rows,
             allregions_rows,
-            additional_toplevel_headers=allregions_rows[0],
+            toplevel_hxltags=allregions_rows[1],
             tab=level,
             toplevel=toplevel,
         )
